/* This file is part of a Windows32 DLL Interface to:
   GNU gettext - internationalization aids
   Copyright (C) 1996, 1998 Free Software Foundation, Inc.

   This file was written by Franco Bez <franco.bez@gmx.de>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

#include <windows.h>

#include "safe_gettext_dll.h" 
// replaces libintl.h 


ClsGettext clsGettext; // the global Gettext Object

ClsGettext::ClsGettext(){
// Loads Library - and gets the function pointers if possible
	hGettextLib=LoadLibrary("gnu_gettext.dll");
	if(!hGettextLib){ // DLL not found
		pGettext       =NULL;
		pDGettext      =NULL;
		pDCGettext     =NULL;
		pTextdomain    =NULL;
		pBindtextdomain=NULL;
		return;
	}
	pGettext       =(pfGettext)        GetProcAddress(hGettextLib,"gettext");
	pDGettext      =(pfDGettext)       GetProcAddress(hGettextLib,"dgettext");
	pDCGettext     =(pfDCGettext)      GetProcAddress(hGettextLib,"dcgettext");
	pTextdomain    =(pfTextdomain)     GetProcAddress(hGettextLib,"textdomain");
	pBindtextdomain=(pfBindtextdomain) GetProcAddress(hGettextLib,"bindtextdomain");
}

ClsGettext::~ClsGettext(){
// Free Library if loaded
	if(hGettextLib)
		FreeLibrary(hGettextLib);
}

// the functions below call the matching DLL function if possible ( DLL was found )
char *ClsGettext::m_Gettext(const char *szMsgId){
	if(pGettext) // Function pointer loaded
		return (*pGettext)(szMsgId);
	return (char *) szMsgId; // do nothing
}

char *ClsGettext::m_dGettext(const char *szDomain,const char *szMsgId){
	if(pDGettext) // Function pointer loaded
		return (*pDGettext)(szDomain,szMsgId);
	return (char *) szMsgId; // do nothing
}

char *ClsGettext::m_dcGettext(const char *szDomain,const char *szMsgId,int iCategory){
	if(pDCGettext) // Function pointer loaded
		return (*pDCGettext)(szDomain,szMsgId,iCategory);
	return (char *) szMsgId; // do nothing
}

char *ClsGettext::m_Textdomain(const char *szDomain){
	if(pTextdomain) // Function pointer loaded
		return (*pTextdomain)(szDomain);
	return (char *) szDomain; // do nothing
}

char *ClsGettext::m_Bindtextdomain(const char *szDomain,const char *szDirectory){
	if(pBindtextdomain) // Function pointer loaded
		return (*pBindtextdomain)(szDomain,szDirectory);
	return (char *) szDirectory; // do nothing
}

// Now the safe gettext dll functions
extern "C"{

char *gettext(const char *szMsgId){
	return clsGettext.m_Gettext(szMsgId);
}

char *dgettext(const char *szDomain,const char *szMsgId){
	return clsGettext.m_dGettext(szDomain,szMsgId);
}

char *dcgettext(const char *szDomain,const char *szMsgId,int iCategory){
	return clsGettext.m_dcGettext(szDomain,szMsgId,iCategory);
}

char *textdomain(const char *szDomain){
	return clsGettext.m_Textdomain(szDomain);
}

char *bindtextdomain(const char *szDomain,const char *szDirectory){
	return clsGettext.m_Bindtextdomain(szDomain,szDirectory);
}

} // extern "C"
